﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using Syncfusion.Windows.Controls.Gantt;
using System.Windows;

namespace EssentialGantt
{
    class ViewModel 
    {
        public ViewModel()
        {
            _resourceCollection = this.GetResources();
            _taskCollection = this.GetData();
        }

        private ObservableCollection<TaskDetails> _taskCollection;

        /// <summary>
        /// Gets or sets the appointment item source.
        /// </summary>
        /// <value>The appointment item source.</value>
        public ObservableCollection<TaskDetails> TaskCollection
        {
            get
            {
                return _taskCollection;
            }
            set
            {
                _taskCollection = value;
            }
        }

        private ObservableCollection<Resource> _resourceCollection;

        /// <summary>
        /// Gets or sets the gantt resources.
        /// </summary>
        /// <value>The gantt resources.</value>
        public ObservableCollection<Resource> ResourceCollection
        {
            get
            {
                return _resourceCollection;
            }
            set
            {
                _resourceCollection = value;
            }
        }

        /// <summary>
        /// Gets the resources.
        /// </summary>
        /// <returns></returns>
        private ObservableCollection<Resource> GetResources()
        {
            ObservableCollection<Resource> Resources = new ObservableCollection<Resource>();

            Resources.Add(new Resource { ID = 1, Name = "R & D" });
            Resources.Add(new Resource { ID = 2, Name = "Analyzers" });
            Resources.Add(new Resource { ID = 3, Name = "Product Definer" });
            Resources.Add(new Resource { ID = 4, Name = "Risk Management" });
            Resources.Add(new Resource { ID = 5, Name = "Budgeting Team" });
            Resources.Add(new Resource { ID = 6, Name = "Developers" });
            Resources.Add(new Resource { ID = 7, Name = "Testers" });
            Resources.Add(new Resource { ID = 8, Name = "Reviewer" });

            return Resources;
        }

        /// <summary>
        /// Gets the data.
        /// </summary>
        /// <returns></returns>
        public ObservableCollection<TaskDetails> GetData()
        {
            ObservableCollection<TaskDetails> Activities = new ObservableCollection<TaskDetails>();

            Activities.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 2), FinishDate = new DateTime(2010, 6, 3), TaskName = "Analysing Market Scope of the Product", TaskId = 1 });

            ObservableCollection<IGanttTask> MarketAnalysis = new ObservableCollection<IGanttTask>();
            MarketAnalysis.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 2, 3, 0, 0), FinishDate = new DateTime(2010, 6, 2, 6, 0, 0), TaskName = "Current Market Review", TaskId = 2 });
            MarketAnalysis.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 2, 6, 0, 0), FinishDate = new DateTime(2010, 6, 2, 9, 0, 0), TaskName = "Establish mislestone for future development", TaskId = 3 });
            MarketAnalysis.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 2, 9, 0, 0), FinishDate = new DateTime(2010, 6, 2, 11, 0, 0), TaskName = "Establish goals", TaskId = 4 });
            MarketAnalysis.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 2, 11, 0, 0), FinishDate = new DateTime(2010, 6, 2, 13, 0, 0), TaskName = "Sales, marketing and pricing plan", TaskId = 5 });
            MarketAnalysis.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 2, 13, 0, 0), FinishDate = new DateTime(2010, 6, 2, 19, 0, 0), TaskName = "Define product goals and milestones", TaskId = 6 });
            MarketAnalysis.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 3, 9, 0, 0), FinishDate = new DateTime(2010, 6, 3, 11, 0, 0), TaskName = "Organization status review", TaskId = 7 });
            MarketAnalysis.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 3, 11, 0, 0), FinishDate = new DateTime(2010, 6, 3, 15, 0, 0), TaskName = "Market Scope of Product clarified", TaskId = 8 });
            ObservableCollection<Predecessor> mrkPredecessor = new ObservableCollection<Predecessor>();
            mrkPredecessor.Add(new Predecessor { GanttTaskIndex = 2, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            mrkPredecessor.Add(new Predecessor { GanttTaskIndex = 3, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            mrkPredecessor.Add(new Predecessor { GanttTaskIndex = 4, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            mrkPredecessor.Add(new Predecessor { GanttTaskIndex = 5, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            mrkPredecessor.Add(new Predecessor { GanttTaskIndex = 6, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            mrkPredecessor.Add(new Predecessor { GanttTaskIndex = 7, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            MarketAnalysis[6].Predecessor = mrkPredecessor;

            MarketAnalysis[0].Resources.Add(this.ResourceCollection[0]);
            MarketAnalysis[1].Resources.Add(this.ResourceCollection[0]);
            MarketAnalysis[2].Resources.Add(this.ResourceCollection[0]);
            MarketAnalysis[3].Resources.Add(this.ResourceCollection[0]);
            MarketAnalysis[4].Resources.Add(this.ResourceCollection[0]);
            MarketAnalysis[5].Resources.Add(this.ResourceCollection[0]);
            Activities[0].Child = MarketAnalysis;


            Activities.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 3), FinishDate = new DateTime(2010, 6, 4), TaskName = "Infrastructure for Product Planning", TaskId =9 });
            ObservableCollection<IGanttTask> InfrastructureReq = new ObservableCollection<IGanttTask>();
            InfrastructureReq.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 3, 3, 0, 0), FinishDate = new DateTime(2010, 6, 3, 6, 0, 0), TaskName = "Define procedure for qualifying ideas", TaskId=10 });
            InfrastructureReq.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 3, 9, 0, 0), FinishDate = new DateTime(2010, 6, 2, 12, 0, 0), TaskName = "Define process for idea sharing", TaskId=11 });
            InfrastructureReq.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 3, 12, 0, 0), FinishDate = new DateTime(2010, 6, 3, 17, 0, 0), TaskName = "Infrastructure for Product planning Complete", TaskId=12 });
            InfrastructureReq[1].Predecessor.Add(new Predecessor { GanttTaskIndex = 10, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            InfrastructureReq[2].Predecessor.Add(new Predecessor { GanttTaskIndex = 11, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });

            InfrastructureReq[0].Resources.Add(this.ResourceCollection[0]);
            InfrastructureReq[1].Resources.Add(this.ResourceCollection[0]);
            InfrastructureReq[2].Resources.Add(this.ResourceCollection[0]);

            Activities[1].Child = InfrastructureReq;

            Activities.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 4), FinishDate = new DateTime(2010, 6, 5), TaskName = "Product Definition Phase", TaskId = 13 });
            ObservableCollection<IGanttTask> Product = new ObservableCollection<IGanttTask>();
            Product.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 4, 9, 0, 0), FinishDate = new DateTime(2010, 6, 4, 11, 0, 0), TaskName = "Identify product", TaskId = 14 });
            Product.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 4, 11, 0, 0), FinishDate = new DateTime(2010, 6, 4, 14, 0, 0), TaskName = "Identify need for the product", TaskId = 15 });
            Product.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 4, 14, 0, 0), FinishDate = new DateTime(2010, 6, 4, 19, 0, 0), TaskName = "Identify current trend for targets", TaskId = 16 });
            Product.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 4, 19, 0, 0), FinishDate = new DateTime(2010, 6, 4, 21, 0, 0), TaskName = "Define product use and features", TaskId = 17 });
            Product.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 5, 9, 0, 0), FinishDate = new DateTime(2010, 6, 5, 13, 0, 0), TaskName = "Identify competitor product", TaskId = 18 });
            Product.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 5, 13, 0, 0), FinishDate = new DateTime(2010, 6, 5, 15, 0, 0), TaskName = "Product Definition Complete", TaskId = 19 });

            Product[1].Predecessor.Add(new Predecessor { GanttTaskIndex = 14, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            Product[2].Predecessor.Add(new Predecessor { GanttTaskIndex = 15, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            Product[3].Predecessor.Add(new Predecessor { GanttTaskIndex = 16, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            Product[5].Predecessor.Add(new Predecessor { GanttTaskIndex = 16, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            Product[5].Predecessor.Add(new Predecessor { GanttTaskIndex = 17, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            Product[5].Predecessor.Add(new Predecessor { GanttTaskIndex = 18, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });

            Product[0].Resources.Add(this.ResourceCollection[2]);
            Product[1].Resources.Add(this.ResourceCollection[2]);
            Product[2].Resources.Add(this.ResourceCollection[2]);
            Product[3].Resources.Add(this.ResourceCollection[2]);
            Product[4].Resources.Add(this.ResourceCollection[2]);

            Activities[2].Child = Product;

            Activities.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 5), FinishDate = new DateTime(2010, 6, 6), TaskName = "Analysing Customer Requirement", TaskId=20 });
            ObservableCollection<IGanttTask> Customer = new ObservableCollection<IGanttTask>();
            Customer.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 5, 9, 0,0), FinishDate = new DateTime(2010, 6, 5, 10, 0, 0), TaskName = "Identify Consumer of Products", TaskId=21 });
            Customer.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 5, 10, 0, 0), FinishDate = new DateTime(2010, 6, 5, 13, 0, 0), TaskName = "Identify Customer Requirement", TaskId=22 });
            Customer.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 5, 14, 0, 0), FinishDate = new DateTime(2010, 6, 5, 17, 0, 0), TaskName = "Analysing Customer Requiremet with current plan", TaskId=23 });
            Customer.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 6, 9, 0, 0), FinishDate = new DateTime(2010, 6, 6, 12, 0, 0), TaskName = "Design based on Customer Requirement", TaskId=24 });
            Customer.Add(new TaskDetails { StartDate = new DateTime(2010, 6, 6, 15, 0, 0), FinishDate = new DateTime(2010, 6, 6, 17, 0, 0), TaskName = "Customer Requirement Analysis Complete", TaskId=25 });
            Customer[1].Predecessor.Add(new Predecessor { GanttTaskIndex = 21, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            Customer[2].Predecessor.Add(new Predecessor { GanttTaskIndex = 22, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            Customer[3].Predecessor.Add(new Predecessor { GanttTaskIndex = 23, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });
            Customer[4].Predecessor.Add(new Predecessor { GanttTaskIndex = 24, GanttTaskRelationship = GanttTaskRelationship.FinishToStart });

            Customer[0].Resources.Add(this.ResourceCollection[1]);
            Customer[1].Resources.Add(this.ResourceCollection[1]);
            Customer[2].Resources.Add(this.ResourceCollection[1]);
            Customer[3].Resources.Add(this.ResourceCollection[1]);

            Activities[3].Child = Customer;

            Activities.Add(new TaskDetails { StartDate = new DateTime(2010, 12, 10), FinishDate = new DateTime(2010, 12, 10), TaskName = "Product Released Successfully", TaskId=70 });

            return Activities;
        }
    }       
}